summaryrefslogtreecommitdiff
path: root/gst/gstclock.h
diff options
context:
space:
mode:
authorWim Taymans <wim.taymans@gmail.com>2007-04-05 10:06:20 +0000
committerWim Taymans <wim.taymans@gmail.com>2007-04-05 10:06:20 +0000
commita78857c2968d9e980ccb84a0c418025c6dc5c403 (patch)
treeb4bd871bf69fde2a49002874979c350e0049e5f9 /gst/gstclock.h
parent94e18e225648a65a84c9deabe1c6fcbda811d707 (diff)
Improve _adjust_unlocked() so that it overflows less.
Original commit message from CVS: * docs/gst/gstreamer-sections.txt: * gst/gstclock.c: (gst_clock_adjust_unlocked), (gst_clock_unadjust_unlocked), (gst_clock_set_calibration): * gst/gstclock.h: Improve _adjust_unlocked() so that it overflows less. Add gst_clock_unadjust_unlocked to convert from external time to internal time based on calibration. Add some more debug. API: GstClock::gst_clock_unadjust_unlocked()
Diffstat (limited to 'gst/gstclock.h')
-rw-r--r--gst/gstclock.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/gst/gstclock.h b/gst/gstclock.h
index d44a47e22..7cdbb33a2 100644
--- a/gst/gstclock.h
+++ b/gst/gstclock.h
@@ -477,9 +477,10 @@ gboolean gst_clock_add_observation (GstClock *clock, GstClockTime slave,
GstClockTime master, gdouble *r_squared);
/* getting and adjusting internal time */
GstClockTime gst_clock_get_internal_time (GstClock *clock);
GstClockTime gst_clock_adjust_unlocked (GstClock *clock, GstClockTime internal);
+GstClockTime gst_clock_unadjust_unlocked (GstClock * clock, GstClockTime external);
/* creating IDs that can be used to get notifications */
@@ -477,9 +477,10 @@ gboolean gst_clock_add_observation (GstClock *clock, GstClockTime slave,
GstClockTime master, gdouble *r_squared);
-/* getting and adjusting internal time */
+/* getting and adjusting internal/external time */
GstClockTime gst_clock_get_internal_time (GstClock *clock);
GstClockTime gst_clock_adjust_unlocked (GstClock *clock, GstClockTime internal);